Pypopt: Ipopt for Python
========================

Pypopt is an Ipopt wrapper for Python. The aim is to expose the same
API as Ipopt C++ interface.


Example
-------

TODO


Requirements
------------

 * A working C++ compiler
 * Cython
 * Ipopt
 * Pytest + pytest-runner + pytest-cov for testing


Installation
------------

To install `pypopt` simply run::

	python setup.py install


If you have Ipopt installed in a different location than ``/usr``::

	IPOPT_INCLUDE_DIR=/path/to/ipopt/include IPOPT_LIBRARY_DIR=/path/to/ipopt/lib python setup.py install


License
-------

Copyright 2018 Francesco Ceccon

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
